@@ -19,11 +19,13 @@
 # qt/kde related
 from PyKDE4.kdecore import KCmdLineArgs, KAboutData, i18n, ki18n
 from PyKDE4.kdecore import KCmdLineOptions
-from PyKDE4.kdeui import KApplication
 
 # std python
 import sys
 
+# local
+from satyr.app import App
+
 def createApp (args=sys.argv):
     #########################################
     # all the bureaucratic init of a KDE App
@@ -33,10 +35,10 @@ def createApp (args=sys.argv):
     appName     = "satyr"
     catalog     = ""
     programName = ki18n ("satyr")                 #ki18n required here
-    version     = "0.3.2"
+    version     = "0.4.0"
     description = ki18n ("I need a media player that thinks about music the way I think about it. This is such a program.")         #ki18n required here
     license     = KAboutData.License_GPL
-    copyright   = ki18n ("(c) 2009 Marcos Dione")    #ki18n required here
+    copyright   = ki18n ("(c) 2009,2010 Marcos Dione")    #ki18n required here
     text        = ki18n ("none")                    #ki18n required here
     homePage    = "http://savannah.nongnu.org/projects/satyr/"
     bugEmail    = "mdione@grulic.org.ar"
@@ -50,11 +52,11 @@ def createApp (args=sys.argv):
 
     KCmdLineArgs.init (args, aboutData)
     options= KCmdLineOptions ()
-    options.add ("s").add ("skin <skin-name>", ki18n ("skin"), "default")
+    options.add ("s").add ("skin <skin-name>", ki18n ("skin"), "")
     options.add ("+path", ki18n ("paths to your music collections"))
     KCmdLineArgs.addCmdLineOptions (options)
 
-    app= KApplication ()
+    app= App ()
     args= KCmdLineArgs.parsedArgs ()
 
     return app, args
