@@ -20,8 +20,8 @@
 # qt/kde related
 from PyKDE4.kdecore import KMimeType, KUrl
 from PyQt4.QtCore import pyqtSignal, QThread, QStringList
-from PyKDE4.phonon import Phonon
-# from PyQt4.phonon import Phonon
+from PyQt4.phonon import Phonon
+# from PyKDE4.phonon import Phonon
 
 # dbus
 import dbus.service
