@@ -19,8 +19,8 @@
 
 
 # qt/kde related
-from PyKDE4.phonon import Phonon
-# from PyQt4.phonon import Phonon
+# from PyKDE4.phonon import Phonon
+from PyQt4.phonon import Phonon
 from PyQt4.QtCore import pyqtSignal, QString
 
 # dbus
@@ -52,13 +52,7 @@ class Player (SatyrObject):
 
         self.playlist= playlist
 
-        # self.media= Phonon.MediaObject ()
-        # self.ao= Phonon.AudioOutput (Phonon.MusicCategory, parent)
-        # BUG: argument 2 of createPath() has an invalid type
-        # but this used to work with PyQt4.phonon
-        # Phonon.createPath (self.media, self.ao)
         self.media= Phonon.createPlayer (Phonon.MusicCategory)
-        # god bless PyQt4.5
         self.media.finished.connect (self.next)
         self.media.stateChanged.connect (self.stateChanged)
 
@@ -172,6 +166,7 @@ class Player (SatyrObject):
         # save them in 'order'
         self.saveConfig ()
         self.playlist.saveConfig ()
+        self.playlist.collaggr.saveConfig ()
         for collection in self.playlist.collections:
             collection.saveConfig ()
         print "bye!"
